==> gorilla-notes-0.2.0-20200815.230532-2.jar: public/js/compiled/cljs-runtime/module$node_modules$d3_force$dist$d3_force.js <==
shadow$provide.module$node_modules$d3_force$dist$d3_force=function(global$jscomp$0,require,module,exports$jscomp$0){(function(global,factory){"object"===typeof exports$jscomp$0&&"undefined"!==typeof module?factory(exports$jscomp$0,require("module$node_modules$d3_quadtree$dist$d3_quadtree"),require("module$node_modules$d3_dispatch$dist$d3_dispatch"),require("module$node_modules$d3_timer$dist$d3_timer")):"function"===typeof define&&define.amd?define(["exports","d3-quadtree","d3-dispatch","d3-timer"],
factory):factory(global.d3=global.d3||{},global.d3,global.d3,global.d3)})(this,function(exports,d3Quadtree,d3Dispatch,d3Timer){function constant(x){return function(){return x}}function jiggle(){return 1E-6*(Math.random()-.5)}function x$jscomp$0(d){return d.x+d.vx}function y$jscomp$0(d){return d.y+d.vy}function index(d){return d.index}function find(nodeById,nodeId){nodeById=nodeById.get(nodeId);if(!nodeById)throw Error("missing: "+nodeId);return nodeById}function x$1(d){return d.x}function y$1(d){return d.y}
var initialAngle=Math.PI*(3-Math.sqrt(5));exports.forceCenter=function(x,y){function force(){var i,n=nodes.length,sx=0,sy=0;for(i=0;i<n;++i){var node=nodes[i];sx+=node.x;sy+=node.y}sx=sx/n-x;sy=sy/n-y;for(i=0;i<n;++i)node=nodes[i],node.x-=sx,node.y-=sy}var nodes;null==x&&(x=0);null==y&&(y=0);force.initialize=function(_){nodes=_};force.x=function(_){return arguments.length?(x=+_,force):x};force.y=function(_){return arguments.length?(y=+_,force):y};return force};exports.forceCollide=function(radius){function force(){function apply(quad,
x0,y0,x1,y1){var data=quad.data;quad=quad.r;var r=ri+quad;if(data)data.index>node.index&&(x0=xi-data.x-data.vx,y0=yi-data.y-data.vy,x1=x0*x0+y0*y0,x1<r*r&&(0===x0&&(x0=jiggle(),x1+=x0*x0),0===y0&&(y0=jiggle(),x1+=y0*y0),x1=(r-(x1=Math.sqrt(x1)))/x1*strength,node.vx+=(x0*=x1)*(r=(quad*=quad)/(ri2+quad)),node.vy+=(y0*=x1)*r,data.vx-=x0*(r=1-r),data.vy-=y0*r));else return x0>xi+r||x1<xi-r||y0>yi+r||y1<yi-r}for(var i,n=nodes.length,tree,node,xi,yi,ri,ri2,k=0;k<iterations;++k)for(tree=d3Quadtree.quadtree(nodes,
x$jscomp$0,y$jscomp$0).visitAfter(prepare),i=0;i<n;++i)node=nodes[i],ri=radii[node.index],ri2=ri*ri,xi=node.x+node.vx,yi=node.y+node.vy,tree.visit(apply)}function prepare(quad){if(quad.data)return quad.r=radii[quad.data.index];for(var i=quad.r=0;4>i;++i)quad[i]&&quad[i].r>quad.r&&(quad.r=quad[i].r)}function initialize(){if(nodes){var i,n=nodes.length;radii=Array(n);for(i=0;i<n;++i){var node=nodes[i];radii[node.index]=+radius(node,i,nodes)}}}var nodes,radii,strength=1,iterations=1;"function"!==typeof radius&&
(radius=constant(null==radius?1:+radius));force.initialize=function(_){nodes=_;initialize()};force.iterations=function(_){return arguments.length?(iterations=+_,force):iterations};force.strength=function(_){return arguments.length?(strength=+_,force):strength};force.radius=function(_){return arguments.length?(radius="function"===typeof _?_:constant(+_),initialize(),force):radius};return force};exports.forceLink=function(links){function force(alpha){for(var k=0,n=links.length;k<iterations;++k)for(var i=
0,link,source,x,y,l;i<n;++i)link=links[i],source=link.source,link=link.target,x=link.x+link.vx-source.x-source.vx||jiggle(),y=link.y+link.vy-source.y-source.vy||jiggle(),l=Math.sqrt(x*x+y*y),l=(l-distances[i])/l*alpha*strengths[i],x*=l,y*=l,link.vx-=x*(l=bias[i]),link.vy-=y*l,source.vx+=x*(l=1-l),source.vy+=y*l}function initialize(){if(nodes){var n=nodes.length,m=links.length,nodeById=new Map(nodes.map(function(d,i){return[id(d,i,nodes),d]}));var i$jscomp$0=0;for(count=Array(n);i$jscomp$0<m;++i$jscomp$0)n=
links[i$jscomp$0],n.index=i$jscomp$0,"object"!==typeof n.source&&(n.source=find(nodeById,n.source)),"object"!==typeof n.target&&(n.target=find(nodeById,n.target)),count[n.source.index]=(count[n.source.index]||0)+1,count[n.target.index]=(count[n.target.index]||0)+1;i$jscomp$0=0;for(bias=Array(m);i$jscomp$0<m;++i$jscomp$0)n=links[i$jscomp$0],bias[i$jscomp$0]=count[n.source.index]/(count[n.source.index]+count[n.target.index]);strengths=Array(m);initializeStrength();distances=Array(m);initializeDistance()}}
function initializeStrength(){if(nodes)for(var i=0,n=links.length;i<n;++i)strengths[i]=+strength(links[i],i,links)}function initializeDistance(){if(nodes)for(var i=0,n=links.length;i<n;++i)distances[i]=+distance(links[i],i,links)}var id=index,strength=function(link){return 1/Math.min(count[link.source.index],count[link.target.index])},strengths,distance=constant(30),distances,nodes,count,bias,iterations=1;null==links&&(links=[]);force.initialize=function(_){nodes=_;initialize()};force.links=function(_){return arguments.length?
(links=_,initialize(),force):links};force.id=function(_){return arguments.length?(id=_,force):id};force.iterations=function(_){return arguments.length?(iterations=+_,force):iterations};force.strength=function(_){return arguments.length?(strength="function"===typeof _?_:constant(+_),initializeStrength(),force):strength};force.distance=function(_){return arguments.length?(distance="function"===typeof _?_:constant(+_),initializeDistance(),force):distance};return force};exports.forceManyBody=function(){function force(_){var n=
nodes.length,tree=d3Quadtree.quadtree(nodes,x$1,y$1).visitAfter(accumulate);alpha=_;for(_=0;_<n;++_)node$jscomp$0=nodes[_],tree.visit(apply)}function initialize(){if(nodes){var i,n=nodes.length;strengths=Array(n);for(i=0;i<n;++i){var node=nodes[i];strengths[node.index]=+strength$jscomp$0(node,i,nodes)}}}function accumulate(quad){var strength=0,q,c,weight=0,x,y,i;if(quad.length){for(x=y=i=0;4>i;++i)(q=quad[i])&&(c=Math.abs(q.value))&&(strength+=q.value,weight+=c,x+=c*q.x,y+=c*q.y);quad.x=x/weight;
quad.y=y/weight}else{q=quad;q.x=q.data.x;q.y=q.data.y;do strength+=strengths[q.data.index];while(q=q.next)}quad.value=strength}function apply(quad,x1,_,x2){if(!quad.value)return!0;_=quad.x-node$jscomp$0.x;var y=quad.y-node$jscomp$0.y;x1=x2-x1;x2=_*_+y*y;if(x1*x1/theta2<x2)return x2<distanceMax2&&(0===_&&(_=jiggle(),x2+=_*_),0===y&&(y=jiggle(),x2+=y*y),x2<distanceMin2&&(x2=Math.sqrt(distanceMin2*x2)),node$jscomp$0.vx+=_*quad.value*alpha/x2,node$jscomp$0.vy+=y*quad.value*alpha/x2),!0;if(!(quad.length||
x2>=distanceMax2)){if(quad.data!==node$jscomp$0||quad.next)0===_&&(_=jiggle(),x2+=_*_),0===y&&(y=jiggle(),x2+=y*y),x2<distanceMin2&&(x2=Math.sqrt(distanceMin2*x2));do quad.data!==node$jscomp$0&&(x1=strengths[quad.data.index]*alpha/x2,node$jscomp$0.vx+=_*x1,node$jscomp$0.vy+=y*x1);while(quad=quad.next)}}var nodes,node$jscomp$0,alpha,strength$jscomp$0=constant(-30),strengths,distanceMin2=1,distanceMax2=Infinity,theta2=.81;force.initialize=function(_){nodes=_;initialize()};force.strength=function(_){return arguments.length?
(strength$jscomp$0="function"===typeof _?_:constant(+_),initialize(),force):strength$jscomp$0};force.distanceMin=function(_){return arguments.length?(distanceMin2=_*_,force):Math.sqrt(distanceMin2)};force.distanceMax=function(_){return arguments.length?(distanceMax2=_*_,force):Math.sqrt(distanceMax2)};force.theta=function(_){return arguments.length?(theta2=_*_,force):Math.sqrt(theta2)};return force};exports.forceRadial=function(radius,x,y){function force(alpha){for(var i=0,n=nodes.length;i<n;++i){var node=
nodes[i],dx=node.x-x||1E-6,dy=node.y-y||1E-6,r=Math.sqrt(dx*dx+dy*dy);r=(radiuses[i]-r)*strengths[i]*alpha/r;node.vx+=dx*r;node.vy+=dy*r}}function initialize(){if(nodes){var i,n=nodes.length;strengths=Array(n);radiuses=Array(n);for(i=0;i<n;++i)radiuses[i]=+radius(nodes[i],i,nodes),strengths[i]=isNaN(radiuses[i])?0:+strength(nodes[i],i,nodes)}}var nodes,strength=constant(.1),strengths,radiuses;"function"!==typeof radius&&(radius=constant(+radius));null==x&&(x=0);null==y&&(y=0);force.initialize=function(_){nodes=
_;initialize()};force.strength=function(_){return arguments.length?(strength="function"===typeof _?_:constant(+_),initialize(),force):strength};force.radius=function(_){return arguments.length?(radius="function"===typeof _?_:constant(+_),initialize(),force):radius};force.x=function(_){return arguments.length?(x=+_,force):x};force.y=function(_){return arguments.length?(y=+_,force):y};return force};exports.forceSimulation=function(nodes){function step(){tick();event.call("tick",simulation);alpha<alphaMin&&
(stepper.stop(),event.call("end",simulation))}function tick(iterations){var i,n=nodes.length;void 0===iterations&&(iterations=1);for(var k=0;k<iterations;++k)for(alpha+=(alphaTarget-alpha)*alphaDecay,forces.forEach(function(force){force(alpha)}),i=0;i<n;++i){var node=nodes[i];null==node.fx?node.x+=node.vx*=velocityDecay:(node.x=node.fx,node.vx=0);null==node.fy?node.y+=node.vy*=velocityDecay:(node.y=node.fy,node.vy=0)}return simulation}function initializeNodes(){for(var i=0,n=nodes.length,node;i<n;++i){node=
nodes[i];node.index=i;null!=node.fx&&(node.x=node.fx);null!=node.fy&&(node.y=node.fy);if(isNaN(node.x)||isNaN(node.y)){var radius=10*Math.sqrt(i),angle=i*initialAngle;node.x=radius*Math.cos(angle);node.y=radius*Math.sin(angle)}if(isNaN(node.vx)||isNaN(node.vy))node.vx=node.vy=0}}function initializeForce(force){force.initialize&&force.initialize(nodes);return force}var simulation,alpha=1,alphaMin=.001,alphaDecay=1-Math.pow(alphaMin,1/300),alphaTarget=0,velocityDecay=.6,forces=new Map,stepper=d3Timer.timer(step),
event=d3Dispatch.dispatch("tick","end");null==nodes&&(nodes=[]);initializeNodes();return simulation={tick:tick,restart:function(){return stepper.restart(step),simulation},stop:function(){return stepper.stop(),simulation},nodes:function(_){return arguments.length?(nodes=_,initializeNodes(),forces.forEach(initializeForce),simulation):nodes},alpha:function(_){return arguments.length?(alpha=+_,simulation):alpha},alphaMin:function(_){return arguments.length?(alphaMin=+_,simulation):alphaMin},alphaDecay:function(_){return arguments.length?
(alphaDecay=+_,simulation):+alphaDecay},alphaTarget:function(_){return arguments.length?(alphaTarget=+_,simulation):alphaTarget},velocityDecay:function(_){return arguments.length?(velocityDecay=1-_,simulation):1-velocityDecay},force:function(name,_){return 1<arguments.length?(null==_?forces.delete(name):forces.set(name,initializeForce(_)),simulation):forces.get(name)},find:function(x,y,radius){var i,n=nodes.length;radius=null==radius?Infinity:radius*radius;for(i=0;i<n;++i){var node=nodes[i];var dx=
x-node.x;var dy=y-node.y;dx=dx*dx+dy*dy;if(dx<radius){var closest=node;radius=dx}}return closest},on:function(name,_){return 1<arguments.length?(event.on(name,_),simulation):event.on(name)}}};exports.forceX=function(x){function force(alpha){for(var i=0,n=nodes.length,node;i<n;++i)node=nodes[i],node.vx+=(xz[i]-node.x)*strengths[i]*alpha}function initialize(){if(nodes){var i,n=nodes.length;strengths=Array(n);xz=Array(n);for(i=0;i<n;++i)strengths[i]=isNaN(xz[i]=+x(nodes[i],i,nodes))?0:+strength(nodes[i],
i,nodes)}}var strength=constant(.1),nodes,strengths,xz;"function"!==typeof x&&(x=constant(null==x?0:+x));force.initialize=function(_){nodes=_;initialize()};force.strength=function(_){return arguments.length?(strength="function"===typeof _?_:constant(+_),initialize(),force):strength};force.x=function(_){return arguments.length?(x="function"===typeof _?_:constant(+_),initialize(),force):x};return force};exports.forceY=function(y){function force(alpha){for(var i=0,n=nodes.length,node;i<n;++i)node=nodes[i],
node.vy+=(yz[i]-node.y)*strengths[i]*alpha}function initialize(){if(nodes){var i,n=nodes.length;strengths=Array(n);yz=Array(n);for(i=0;i<n;++i)strengths[i]=isNaN(yz[i]=+y(nodes[i],i,nodes))?0:+strength(nodes[i],i,nodes)}}var strength=constant(.1),nodes,strengths,yz;"function"!==typeof y&&(y=constant(null==y?0:+y));force.initialize=function(_){nodes=_;initialize()};force.strength=function(_){return arguments.length?(strength="function"===typeof _?_:constant(+_),initialize(),force):strength};force.y=
function(_){return arguments.length?(y="function"===typeof _?_:constant(+_),initialize(),force):y};return force};Object.defineProperty(exports,"__esModule",{value:!0})})}
//# sourceMappingURL=module$node_modules$d3_force$dist$d3_force.js.map

==> gorilla-notes-0.4.0-20200914.094953-4.jar: public/js/compiled/cljs-runtime/module$node_modules$d3_force$dist$d3_force.js <==
import "./cljs_env.js";
shadow$provide.module$node_modules$d3_force$dist$d3_force=function(global$jscomp$0,require,module,exports$jscomp$0){(function(global,factory){"object"===typeof exports$jscomp$0&&"undefined"!==typeof module?factory(exports$jscomp$0,require("module$node_modules$d3_quadtree$dist$d3_quadtree"),require("module$node_modules$d3_dispatch$dist$d3_dispatch"),require("module$node_modules$d3_timer$dist$d3_timer")):"function"===typeof define&&define.amd?define(["exports","d3-quadtree","d3-dispatch","d3-timer"],
factory):factory(global.d3=global.d3||{},global.d3,global.d3,global.d3)})(this,function(exports,d3Quadtree,d3Dispatch,d3Timer){function constant(x){return function(){return x}}function jiggle(){return 1E-6*(Math.random()-.5)}function x$jscomp$0(d){return d.x+d.vx}function y$jscomp$0(d){return d.y+d.vy}function index(d){return d.index}function find(nodeById,nodeId){nodeById=nodeById.get(nodeId);if(!nodeById)throw Error("missing: "+nodeId);return nodeById}function x$1(d){return d.x}function y$1(d){return d.y}
var initialAngle=Math.PI*(3-Math.sqrt(5));exports.forceCenter=function(x,y){function force(){var i,n=nodes.length,sx=0,sy=0;for(i=0;i<n;++i){var node=nodes[i];sx+=node.x;sy+=node.y}sx=sx/n-x;sy=sy/n-y;for(i=0;i<n;++i)node=nodes[i],node.x-=sx,node.y-=sy}var nodes;null==x&&(x=0);null==y&&(y=0);force.initialize=function(_){nodes=_};force.x=function(_){return arguments.length?(x=+_,force):x};force.y=function(_){return arguments.length?(y=+_,force):y};return force};exports.forceCollide=function(radius){function force(){function apply(quad,
x0,y0,x1,y1){var data=quad.data;quad=quad.r;var r=ri+quad;if(data)data.index>node.index&&(x0=xi-data.x-data.vx,y0=yi-data.y-data.vy,x1=x0*x0+y0*y0,x1<r*r&&(0===x0&&(x0=jiggle(),x1+=x0*x0),0===y0&&(y0=jiggle(),x1+=y0*y0),x1=(r-(x1=Math.sqrt(x1)))/x1*strength,node.vx+=(x0*=x1)*(r=(quad*=quad)/(ri2+quad)),node.vy+=(y0*=x1)*r,data.vx-=x0*(r=1-r),data.vy-=y0*r));else return x0>xi+r||x1<xi-r||y0>yi+r||y1<yi-r}for(var i,n=nodes.length,tree,node,xi,yi,ri,ri2,k=0;k<iterations;++k)for(tree=d3Quadtree.quadtree(nodes,
x$jscomp$0,y$jscomp$0).visitAfter(prepare),i=0;i<n;++i)node=nodes[i],ri=radii[node.index],ri2=ri*ri,xi=node.x+node.vx,yi=node.y+node.vy,tree.visit(apply)}function prepare(quad){if(quad.data)return quad.r=radii[quad.data.index];for(var i=quad.r=0;4>i;++i)quad[i]&&quad[i].r>quad.r&&(quad.r=quad[i].r)}function initialize(){if(nodes){var i,n=nodes.length;radii=Array(n);for(i=0;i<n;++i){var node=nodes[i];radii[node.index]=+radius(node,i,nodes)}}}var nodes,radii,strength=1,iterations=1;"function"!==typeof radius&&
(radius=constant(null==radius?1:+radius));force.initialize=function(_){nodes=_;initialize()};force.iterations=function(_){return arguments.length?(iterations=+_,force):iterations};force.strength=function(_){return arguments.length?(strength=+_,force):strength};force.radius=function(_){return arguments.length?(radius="function"===typeof _?_:constant(+_),initialize(),force):radius};return force};exports.forceLink=function(links){function force(alpha){for(var k=0,n=links.length;k<iterations;++k)for(var i=
0,link,source,x,y,l;i<n;++i)link=links[i],source=link.source,link=link.target,x=link.x+link.vx-source.x-source.vx||jiggle(),y=link.y+link.vy-source.y-source.vy||jiggle(),l=Math.sqrt(x*x+y*y),l=(l-distances[i])/l*alpha*strengths[i],x*=l,y*=l,link.vx-=x*(l=bias[i]),link.vy-=y*l,source.vx+=x*(l=1-l),source.vy+=y*l}function initialize(){if(nodes){var n=nodes.length,m=links.length,nodeById=new Map(nodes.map((d,i)=>[id(d,i,nodes),d]));var i$jscomp$0=0;for(count=Array(n);i$jscomp$0<m;++i$jscomp$0)n=links[i$jscomp$0],
n.index=i$jscomp$0,"object"!==typeof n.source&&(n.source=find(nodeById,n.source)),"object"!==typeof n.target&&(n.target=find(nodeById,n.target)),count[n.source.index]=(count[n.source.index]||0)+1,count[n.target.index]=(count[n.target.index]||0)+1;i$jscomp$0=0;for(bias=Array(m);i$jscomp$0<m;++i$jscomp$0)n=links[i$jscomp$0],bias[i$jscomp$0]=count[n.source.index]/(count[n.source.index]+count[n.target.index]);strengths=Array(m);initializeStrength();distances=Array(m);initializeDistance()}}function initializeStrength(){if(nodes)for(var i=
0,n=links.length;i<n;++i)strengths[i]=+strength(links[i],i,links)}function initializeDistance(){if(nodes)for(var i=0,n=links.length;i<n;++i)distances[i]=+distance(links[i],i,links)}var id=index,strength=function(link){return 1/Math.min(count[link.source.index],count[link.target.index])},strengths,distance=constant(30),distances,nodes,count,bias,iterations=1;null==links&&(links=[]);force.initialize=function(_){nodes=_;initialize()};force.links=function(_){return arguments.length?(links=_,initialize(),
force):links};force.id=function(_){return arguments.length?(id=_,force):id};force.iterations=function(_){return arguments.length?(iterations=+_,force):iterations};force.strength=function(_){return arguments.length?(strength="function"===typeof _?_:constant(+_),initializeStrength(),force):strength};force.distance=function(_){return arguments.length?(distance="function"===typeof _?_:constant(+_),initializeDistance(),force):distance};return force};exports.forceManyBody=function(){function force(_){var n=
nodes.length,tree=d3Quadtree.quadtree(nodes,x$1,y$1).visitAfter(accumulate);alpha=_;for(_=0;_<n;++_)node$jscomp$0=nodes[_],tree.visit(apply)}function initialize(){if(nodes){var i,n=nodes.length;strengths=Array(n);for(i=0;i<n;++i){var node=nodes[i];strengths[node.index]=+strength$jscomp$0(node,i,nodes)}}}function accumulate(quad){var strength=0,q,c,weight=0,x,y,i;if(quad.length){for(x=y=i=0;4>i;++i)(q=quad[i])&&(c=Math.abs(q.value))&&(strength+=q.value,weight+=c,x+=c*q.x,y+=c*q.y);quad.x=x/weight;
quad.y=y/weight}else{q=quad;q.x=q.data.x;q.y=q.data.y;do strength+=strengths[q.data.index];while(q=q.next)}quad.value=strength}function apply(quad,x1,_,x2){if(!quad.value)return!0;_=quad.x-node$jscomp$0.x;var y=quad.y-node$jscomp$0.y;x1=x2-x1;x2=_*_+y*y;if(x1*x1/theta2<x2)return x2<distanceMax2&&(0===_&&(_=jiggle(),x2+=_*_),0===y&&(y=jiggle(),x2+=y*y),x2<distanceMin2&&(x2=Math.sqrt(distanceMin2*x2)),node$jscomp$0.vx+=_*quad.value*alpha/x2,node$jscomp$0.vy+=y*quad.value*alpha/x2),!0;if(!(quad.length||
x2>=distanceMax2)){if(quad.data!==node$jscomp$0||quad.next)0===_&&(_=jiggle(),x2+=_*_),0===y&&(y=jiggle(),x2+=y*y),x2<distanceMin2&&(x2=Math.sqrt(distanceMin2*x2));do quad.data!==node$jscomp$0&&(x1=strengths[quad.data.index]*alpha/x2,node$jscomp$0.vx+=_*x1,node$jscomp$0.vy+=y*x1);while(quad=quad.next)}}var nodes,node$jscomp$0,alpha,strength$jscomp$0=constant(-30),strengths,distanceMin2=1,distanceMax2=Infinity,theta2=.81;force.initialize=function(_){nodes=_;initialize()};force.strength=function(_){return arguments.length?
(strength$jscomp$0="function"===typeof _?_:constant(+_),initialize(),force):strength$jscomp$0};force.distanceMin=function(_){return arguments.length?(distanceMin2=_*_,force):Math.sqrt(distanceMin2)};force.distanceMax=function(_){return arguments.length?(distanceMax2=_*_,force):Math.sqrt(distanceMax2)};force.theta=function(_){return arguments.length?(theta2=_*_,force):Math.sqrt(theta2)};return force};exports.forceRadial=function(radius,x,y){function force(alpha){for(var i=0,n=nodes.length;i<n;++i){var node=
nodes[i],dx=node.x-x||1E-6,dy=node.y-y||1E-6,r=Math.sqrt(dx*dx+dy*dy);r=(radiuses[i]-r)*strengths[i]*alpha/r;node.vx+=dx*r;node.vy+=dy*r}}function initialize(){if(nodes){var i,n=nodes.length;strengths=Array(n);radiuses=Array(n);for(i=0;i<n;++i)radiuses[i]=+radius(nodes[i],i,nodes),strengths[i]=isNaN(radiuses[i])?0:+strength(nodes[i],i,nodes)}}var nodes,strength=constant(.1),strengths,radiuses;"function"!==typeof radius&&(radius=constant(+radius));null==x&&(x=0);null==y&&(y=0);force.initialize=function(_){nodes=
_;initialize()};force.strength=function(_){return arguments.length?(strength="function"===typeof _?_:constant(+_),initialize(),force):strength};force.radius=function(_){return arguments.length?(radius="function"===typeof _?_:constant(+_),initialize(),force):radius};force.x=function(_){return arguments.length?(x=+_,force):x};force.y=function(_){return arguments.length?(y=+_,force):y};return force};exports.forceSimulation=function(nodes){function step(){tick();event.call("tick",simulation);alpha<alphaMin&&
(stepper.stop(),event.call("end",simulation))}function tick(iterations){var i,n=nodes.length;void 0===iterations&&(iterations=1);for(var k=0;k<iterations;++k)for(alpha+=(alphaTarget-alpha)*alphaDecay,forces.forEach(function(force){force(alpha)}),i=0;i<n;++i){var node=nodes[i];null==node.fx?node.x+=node.vx*=velocityDecay:(node.x=node.fx,node.vx=0);null==node.fy?node.y+=node.vy*=velocityDecay:(node.y=node.fy,node.vy=0)}return simulation}function initializeNodes(){for(var i=0,n=nodes.length,node;i<n;++i){node=
nodes[i];node.index=i;null!=node.fx&&(node.x=node.fx);null!=node.fy&&(node.y=node.fy);if(isNaN(node.x)||isNaN(node.y)){var radius=10*Math.sqrt(i),angle=i*initialAngle;node.x=radius*Math.cos(angle);node.y=radius*Math.sin(angle)}if(isNaN(node.vx)||isNaN(node.vy))node.vx=node.vy=0}}function initializeForce(force){force.initialize&&force.initialize(nodes);return force}var simulation,alpha=1,alphaMin=.001,alphaDecay=1-Math.pow(alphaMin,1/300),alphaTarget=0,velocityDecay=.6,forces=new Map,stepper=d3Timer.timer(step),
event=d3Dispatch.dispatch("tick","end");null==nodes&&(nodes=[]);initializeNodes();return simulation={tick,restart:function(){return stepper.restart(step),simulation},stop:function(){return stepper.stop(),simulation},nodes:function(_){return arguments.length?(nodes=_,initializeNodes(),forces.forEach(initializeForce),simulation):nodes},alpha:function(_){return arguments.length?(alpha=+_,simulation):alpha},alphaMin:function(_){return arguments.length?(alphaMin=+_,simulation):alphaMin},alphaDecay:function(_){return arguments.length?
(alphaDecay=+_,simulation):+alphaDecay},alphaTarget:function(_){return arguments.length?(alphaTarget=+_,simulation):alphaTarget},velocityDecay:function(_){return arguments.length?(velocityDecay=1-_,simulation):1-velocityDecay},force:function(name,_){return 1<arguments.length?(null==_?forces.delete(name):forces.set(name,initializeForce(_)),simulation):forces.get(name)},find:function(x,y,radius){var i,n=nodes.length;radius=null==radius?Infinity:radius*radius;for(i=0;i<n;++i){var node=nodes[i];var dx=
x-node.x;var dy=y-node.y;dx=dx*dx+dy*dy;if(dx<radius){var closest=node;radius=dx}}return closest},on:function(name,_){return 1<arguments.length?(event.on(name,_),simulation):event.on(name)}}};exports.forceX=function(x){function force(alpha){for(var i=0,n=nodes.length,node;i<n;++i)node=nodes[i],node.vx+=(xz[i]-node.x)*strengths[i]*alpha}function initialize(){if(nodes){var i,n=nodes.length;strengths=Array(n);xz=Array(n);for(i=0;i<n;++i)strengths[i]=isNaN(xz[i]=+x(nodes[i],i,nodes))?0:+strength(nodes[i],
i,nodes)}}var strength=constant(.1),nodes,strengths,xz;"function"!==typeof x&&(x=constant(null==x?0:+x));force.initialize=function(_){nodes=_;initialize()};force.strength=function(_){return arguments.length?(strength="function"===typeof _?_:constant(+_),initialize(),force):strength};force.x=function(_){return arguments.length?(x="function"===typeof _?_:constant(+_),initialize(),force):x};return force};exports.forceY=function(y){function force(alpha){for(var i=0,n=nodes.length,node;i<n;++i)node=nodes[i],
node.vy+=(yz[i]-node.y)*strengths[i]*alpha}function initialize(){if(nodes){var i,n=nodes.length;strengths=Array(n);yz=Array(n);for(i=0;i<n;++i)strengths[i]=isNaN(yz[i]=+y(nodes[i],i,nodes))?0:+strength(nodes[i],i,nodes)}}var strength=constant(.1),nodes,strengths,yz;"function"!==typeof y&&(y=constant(null==y?0:+y));force.initialize=function(_){nodes=_;initialize()};force.strength=function(_){return arguments.length?(strength="function"===typeof _?_:constant(+_),initialize(),force):strength};force.y=
function(_){return arguments.length?(y="function"===typeof _?_:constant(+_),initialize(),force):y};return force};Object.defineProperty(exports,"__esModule",{value:!0})})}
//# sourceMappingURL=module$node_modules$d3_force$dist$d3_force.js.map
